==> haskell-mono-traversable-1.0.21.0-104-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable
version:              1.0.21.0
visibility:           public
id:                   mono-traversable-1.0.21.0-7ORvxyI1bVCJe51jZHn0i8
key:                  mono-traversable-1.0.21.0-7ORvxyI1bVCJe51jZHn0i8
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, John Wiegley, Greg Weber
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Type classes for mapping, folding, and traversing monomorphic containers

description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>

category:             Data
abi:                  38bad48996c51b7b2e85736a309832ba
exposed:              True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences

hidden-modules:       Paths_mono_traversable
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mono-traversable-1.0.21.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mono-traversable-1.0.21.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mono-traversable-1.0.21.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable
hs-libraries:         HSmono-traversable-1.0.21.0-7ORvxyI1bVCJe51jZHn0i8
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57
    vector-algorithms-0.9.1.0-EhwKZ2FrR67GHUoPSU38UJ

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-1.0.21.0-124-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable
version:              1.0.21.0
visibility:           public
id:                   mono-traversable-1.0.21.0-48l2Xi79dD45KeFaMEMJQI
key:                  mono-traversable-1.0.21.0-48l2Xi79dD45KeFaMEMJQI
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, John Wiegley, Greg Weber
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Type classes for mapping, folding, and traversing monomorphic containers

description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>

category:             Data
abi:                  724668cdbd86d46e43e090553acf4e12
exposed:              True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences

hidden-modules:       Paths_mono_traversable
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mono-traversable-1.0.21.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mono-traversable-1.0.21.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mono-traversable-1.0.21.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable
hs-libraries:         HSmono-traversable-1.0.21.0-48l2Xi79dD45KeFaMEMJQI
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS
    vector-algorithms-0.9.1.0-E6Re4BGH6W6AUhX7AjtMtV

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
